Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5518)

Unified Diff: chrome/browser/cocoa/toolbar_controller.h

Issue 495010: Mac: fix/implement app windows (not app mode), popups, drawing; refactor code. (Closed)
Patch Set: Updated per pink's review. Created 11 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/cocoa/tab_window_controller.mm ('k') | chrome/browser/cocoa/toolbar_controller.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/cocoa/toolbar_controller.h
diff --git a/chrome/browser/cocoa/toolbar_controller.h b/chrome/browser/cocoa/toolbar_controller.h
index 0b96569cb2a98adf41daa891c83a26bfd6842748..83a1b81794df045e2a2e56429ebd63a8161c9d0b 100644
--- a/chrome/browser/cocoa/toolbar_controller.h
+++ b/chrome/browser/cocoa/toolbar_controller.h
@@ -72,7 +72,8 @@ class ToolbarModel;
scoped_ptr<BubblePositioner> bubblePositioner_;
BooleanPrefMember showHomeButton_;
BooleanPrefMember showPageOptionButtons_;
- BOOL hasToolbar_; // if NO, we only have the location bar.
+ BOOL hasToolbar_; // If NO, we may have only the location bar.
+ BOOL hasLocationBar_; // If |hasToolbar_| is YES, this must also be YES.
// We have an extra retain in the locationBar_.
// See comments in awakeFromNib for more info.
@@ -113,7 +114,7 @@ class ToolbarModel;
resizeDelegate:(id<ViewResizer>)resizeDelegate;
// Get the C++ bridge object representing the location bar for this tab.
-- (LocationBar*)locationBar;
+- (LocationBar*)locationBarBridge;
// Called by the Window delegate so we can provide a custom field editor if
// needed.
@@ -138,10 +139,10 @@ class ToolbarModel;
// state.
- (void)setIsLoading:(BOOL)isLoading;
-// Allow turning off the toolbar (but we keep the location bar
-// around). This changes the behavior of other methods, like
-// [self view].
-- (void)setHasToolbar:(BOOL)toolbar;
+// Allow turning off the toolbar (but we may keep the location bar without a
+// surrounding toolbar). If |toolbar| is YES, the value of |hasLocationBar| is
+// ignored. This changes the behavior of other methods, like |-view|.
+- (void)setHasToolbar:(BOOL)toolbar hasLocationBar:(BOOL)locBar;
// The bookmark bubble (when you click the star) needs to know where to go.
// Somewhere near the star button seems like a good start.
« no previous file with comments | « chrome/browser/cocoa/tab_window_controller.mm ('k') | chrome/browser/cocoa/toolbar_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698